% icasreport.cls
%     ICAS Report LaTeX class based on standard article class
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Revisions
%    v 0.0  31/10/2019  First release
%      0.1  08/04/2020  Customization of header logo
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{icasreport}[2019/10/31 ICAS Report]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax

% Base class
\LoadClass[a4paper,11pt,twoside]{article}

% Package dependencies and basic settings
\RequirePackage[utf8]{inputenc} % UTF-8 source text encoding
\RequirePackage[english]{babel} % English language
\RequirePackage{lmodern} % Latin Computer Modern fonts
\renewcommand\familydefault{\sfdefault} % Sans-Serif default
\RequirePackage[T1]{fontenc} % Postscript Type-1 font encoding
\RequirePackage[includeheadfoot, margin=2cm]{geometry} % page layout
\RequirePackage{fancyhdr} % headers and footers
\RequirePackage{graphicx} % graphics stuff
\DeclareGraphicsExtensions{.pdf}
\RequirePackage{xcolor} % coloring
\RequirePackage{hyperref} % all PDF specials
\RequirePackage{url} % formatting URL
\RequirePackage[printonlyused]{acronym} % list of acronyms
\RequirePackage{float} % float positioning
\RequirePackage{caption} % float captions hanged and with bold labels
\RequirePackage{amscd} % math stuff
\RequirePackage{amsmath} % math stuff
\RequirePackage{amstext} % math stuff
\RequirePackage{amssymb} % math stuff
\RequirePackage{amsfonts} % math stuff
\RequirePackage{array} % math tables
\RequirePackage{hhline} % tables
\RequirePackage{multicol} % tables
\RequirePackage{multirow} % tables
\RequirePackage{currfile} % filename
\xdef\myfile{\currfilebase}
\RequirePackage{datetime} % date/time format
\RequirePackage{lastpage} % page count
\RequirePackage[nottoc]{tocbibind} % bibliography in TOC
\RequirePackage{cite} % bibliography cite
\RequirePackage{soul} % highlighting
\sethlcolor{yellow}

% Additional configurable fields
\def\@subtitle{My Subtitle}
\newcommand{\subtitle}[1]{\def\@subtitle{#1}}
\def\@email{yourself@ho.me}
\newcommand{\email}[1]{\def\@email{#1}}
\def\@logo{\includegraphics[width=40mm]{tex/cnm+icas}}
\newcommand{\logo}[1]{\def\@logo{#1}}
\def\@revision{0.0}
\newcommand{\revision}[1]{\def\@revision{#1}}

% PDF metadata
\newcommand{\setPDFmetadata}{%
\hypersetup{
 pdftitle={\@title},
 pdfsubject={\@subtitle},
 pdfauthor={\@author},
 pdfpagemode=UseOutlines,
 pdfstartview=FitH,
 colorlinks=false,
 allbordercolors=lightgray
}}

% Page layout
\geometry{
headheight=15mm,
headsep=5mm,
showframe=false
}
\setlength{\parindent}{0pt}
\setlength{\parskip}{1.5ex}

% Date format
\newdateformat{icasdate}{\THEYEAR/\twodigit{\THEMONTH}/\twodigit{\THEDAY}}

% Headers and footers
\fancyhead{}
\fancyhead[R]{\flushright \icasdate{\today}\\ {\bf CONFIDENTIAL}}
\fancyhead[L]{\@logo}
\fancyfoot{}
\fancyfoot[RO,LE]{{\thepage}/\pageref{LastPage}}
\fancyfoot[LO,RE]{\texttt{\myfile}}
\renewcommand{\headrulewidth}{1pt}
\renewcommand{\footrulewidth}{1pt}

% Float captions
\DeclareCaptionFormat{mycaption}{
\begin{tabular}{r!{\vrule width 0.25mm}l}
#1 & \parbox[t]{0.65\textwidth}{#3}\\
\end{tabular}
}
\captionsetup{
 format=mycaption,
 font=small,
 labelfont=bf,
 margin={10mm,10mm},
 singlelinecheck=false
}

% Frontmatter
\newcommand{\makefront}{%
 %\frontmatter
 \icasdate
 \pagestyle{fancy}
 \selectlanguage{english}
 \setPDFmetadata
 
 \begin{titlepage}
  \begin{center}
   \rule{0mm}{20mm}\\
   {\Huge\textbf{\@title}}\\
   \vspace{3mm}
   {\LARGE\textbf{\@subtitle}}\\
   \vspace{10mm}
   {\Large\@author}\\
   \vspace{3mm}
   {\Large \href{mailto:\@email}{\texttt\@email}}\\
   \vspace{10mm}
   {\Large Integrated Circuits and Systems (ICAS)}\\
   {\Large IMB-CNM(CSIC)}\\
   \vfill
   \begin{center}
   \begin{tabular}{|r|p{8cm}|r|l|}
   \hline
   \textbf{Modification date:} & \icasdate{\today} & \textbf{Revision:} & \@revision\\
   \hline
   \textbf{Document name:} & \texttt{\currfilebase} & \textbf{Number of pages:} & \pageref{LastPage}\\
   \hline
   \end{tabular}\\
   \end{center}
  \end{center}
  \thispagestyle{fancy}
 \end{titlepage}
 
 \newpage
 \fancyhead[CO,CE]{\centering \textbf{\@title}\\ \textbf{\@subtitle}}
 \setlength{\parskip}{0ex}
}

% Bibliography
\bibliographystyle{IEEEtran}
\renewcommand\bibsection{\section*{\refname}}

\endinput
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
